<?php $TRANSLATIONS = array(
"Error (de)activating addressbook." => "Ein feil oppstod ved (de)aktivering av adressebok.",
"Cannot add empty property." => "Kan ikkje leggja til tomt felt.",
"At least one of the address fields has to be filled out." => "Minst eit av adressefelta må fyllast ut.",
"Information about vCard is incorrect. Please reload the page." => "Informasjonen om vCard-et er feil, ver venleg og last sida på nytt.",
"Contacts" => "Kotaktar",
"Download" => "Last ned",
"Edit" => "Endra",
"Delete" => "Slett",
"Cancel" => "Kanseller",
"This is not your addressbook." => "Dette er ikkje di adressebok.",
"Contact could not be found." => "Fann ikkje kontakten.",
"Work" => "Arbeid",
"Home" => "Heime",
"Mobile" => "Mobil",
"Text" => "Tekst",
"Voice" => "Tale",
"Fax" => "Faks",
"Video" => "Video",
"Pager" => "Personsøkjar",
"Birthday" => "Bursdag",
"Contact" => "Kontakt",
"Add Contact" => "Legg til kontakt",
"Organization" => "Organisasjon",
"Preferred" => "Føretrekt",
"Phone" => "Telefonnummer",
"Email" => "Epost",
"Address" => "Adresse",
"Download contact" => "Last ned kontakt",
"Delete contact" => "Slett kontakt",
"Type" => "Skriv",
"PO Box" => "Postboks",
"Extended" => "Utvida",
"City" => "Stad",
"Region" => "Region/fylke",
"Zipcode" => "Postnummer",
"Country" => "Land",
"Addressbook" => "Adressebok",
"Addressbooks" => "Adressebøker",
"New Address Book" => "Ny adressebok",
"Save" => "Lagre"
);
